==> openconfig-models-17.0.0-sources.jar: org/opendaylight/yang/gen/v1/http/openconfig/net/yang/system/logging/rev181121/logging/remote/top/remote/servers/RemoteServerBuilder.java <==
package org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.remote.top.remote.servers;
import java.lang.Class;
import java.lang.IllegalArgumentException;
import java.lang.NullPointerException;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.LoggingSelectorsTop;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.remote.top.remote.servers.remote.server.Config;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.remote.top.remote.servers.remote.server.State;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.selectors.top.Selectors;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.types.inet.rev210107.Host;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link RemoteServer} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     RemoteServer createRemoteServer(int fooXyzzy, int barBaz) {
 *         return new RemoteServerBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of RemoteServer, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization opportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see RemoteServer
 *
 */
@Generated("mdsal-binding-generator")
public class RemoteServerBuilder {

    private Config _config;
    private Host _host;
    private Selectors _selectors;
    private State _state;
    private RemoteServerKey key;


    Map<Class<? extends Augmentation<RemoteServer>>, Augmentation<RemoteServer>> augmentation = Map.of();

    /**
     * Construct an empty builder.
     */
    public RemoteServerBuilder() {
        // No-op
    }

    
    
    /**
     * Construct a new builder initialized from specified {@link LoggingSelectorsTop}.
     *
     * @param arg LoggingSelectorsTop from which the builder should be initialized
     */
    public RemoteServerBuilder(LoggingSelectorsTop arg) {
        this._selectors = arg.getSelectors();
    }
    
    

    /**
     * Construct a builder initialized with state from specified {@link RemoteServer}.
     *
     * @param base RemoteServer from which the builder should be initialized
     */
    public RemoteServerBuilder(RemoteServer base) {
        final var aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this.key = base.key();
        this._host = base.getHost();
        this._config = base.getConfig();
        this._selectors = base.getSelectors();
        this._state = base.getState();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     *   <li>{@link LoggingSelectorsTop}</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types or has property with incompatible value
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof LoggingSelectorsTop castArg) {
            this._selectors = castArg.getSelectors();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[LoggingSelectorsTop]");
    }

    /**
     * Return current value associated with the property corresponding to {@link RemoteServer#key()}.
     *
     * @return current value
     */
    public RemoteServerKey key() {
        return key;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link RemoteServer#getConfig()}.
     *
     * @return current value
     */
    public Config getConfig() {
        return _config;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link RemoteServer#getHost()}.
     *
     * @return current value
     */
    public Host getHost() {
        return _host;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link RemoteServer#getSelectors()}.
     *
     * @return current value
     */
    public Selectors getSelectors() {
        return _selectors;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link RemoteServer#getState()}.
     *
     * @return current value
     */
    public State getState() {
        return _state;
    }

    /**
     * Return the specified augmentation, if it is present in this builder.
     *
     * @param <E$$> augmentation type
     * @param augmentationType augmentation type class
     * @return Augmentation object from this builder, or {@code null} if not present
     * @throws NullPointerException if {@code augmentType} is {@code null}
     */
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<RemoteServer>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    /**
     * Set the key value corresponding to {@link RemoteServer#key()} to the specified
     * value.
     *
     * @param key desired value
     * @return this builder
     */
    public RemoteServerBuilder withKey(final RemoteServerKey key) {
        this.key = key;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link RemoteServer#getConfig()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public RemoteServerBuilder setConfig(final Config value) {
        this._config = value;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link RemoteServer#getHost()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public RemoteServerBuilder setHost(final Host value) {
        this._host = value;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link RemoteServer#getSelectors()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public RemoteServerBuilder setSelectors(final Selectors value) {
        this._selectors = value;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link RemoteServer#getState()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public RemoteServerBuilder setState(final State value) {
        this._state = value;
        return this;
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public RemoteServerBuilder addAugmentation(Augmentation<RemoteServer> augmentation) {
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentation.implementedInterface(), augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public RemoteServerBuilder removeAugmentation(Class<? extends Augmentation<RemoteServer>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    /**
     * A new {@link RemoteServer} instance.
     *
     * @return A new {@link RemoteServer} instance.
     */
    public @NonNull RemoteServer build() {
        return new RemoteServerImpl(this);
    }

    private static final class RemoteServerImpl
        extends AbstractAugmentable<RemoteServer>
        implements RemoteServer {
    
        private final Config _config;
        private final Host _host;
        private final Selectors _selectors;
        private final State _state;
        private final RemoteServerKey key;
    
        RemoteServerImpl(RemoteServerBuilder base) {
            super(base.augmentation);
            if (base.key() != null) {
                this.key = base.key();
            } else {
                this.key = new RemoteServerKey(base.getHost());
            }
            this._host = key.getHost();
            this._config = base.getConfig();
            this._selectors = base.getSelectors();
            this._state = base.getState();
        }
    
        @Override
        public RemoteServerKey key() {
            return key;
        }
        
        @Override
        public Config getConfig() {
            return _config;
        }
        
        @Override
        public Host getHost() {
            return _host;
        }
        
        @Override
        public Selectors getSelectors() {
            return _selectors;
        }
        
        @Override
        public State getState() {
            return _state;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = RemoteServer.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return RemoteServer.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return RemoteServer.bindingToString(this);
        }
    }
}

==> openconfig-models-20.0.0-sources.jar: org/opendaylight/yang/gen/v1/http/openconfig/net/yang/system/logging/rev181121/logging/remote/top/remote/servers/RemoteServerBuilder.java <==
package org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.remote.top.remote.servers;
import java.lang.Class;
import java.lang.IllegalArgumentException;
import java.lang.NullPointerException;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.LoggingSelectorsTop;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.remote.top.remote.servers.remote.server.Config;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.remote.top.remote.servers.remote.server.State;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.selectors.top.Selectors;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.types.inet.rev210107.Host;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link RemoteServer} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     RemoteServer createRemoteServer(int fooXyzzy, int barBaz) {
 *         return new RemoteServerBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of RemoteServer, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization opportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see RemoteServer
 *
 */
@Generated("mdsal-binding-generator")
public class RemoteServerBuilder {

    private Config _config;
    private Host _host;
    private Selectors _selectors;
    private State _state;
    private RemoteServerKey key;


    Map<Class<? extends Augmentation<RemoteServer>>, Augmentation<RemoteServer>> augmentation = Map.of();

    /**
     * Construct an empty builder.
     */
    public RemoteServerBuilder() {
        // No-op
    }

    
    
    /**
     * Construct a new builder initialized from specified {@link LoggingSelectorsTop}.
     *
     * @param arg LoggingSelectorsTop from which the builder should be initialized
     */
    public RemoteServerBuilder(LoggingSelectorsTop arg) {
        this._selectors = arg.getSelectors();
    }
    
    

    /**
     * Construct a builder initialized with state from specified {@link RemoteServer}.
     *
     * @param base RemoteServer from which the builder should be initialized
     */
    public RemoteServerBuilder(RemoteServer base) {
        final var aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this.key = base.key();
        this._host = base.getHost();
        this._config = base.getConfig();
        this._selectors = base.getSelectors();
        this._state = base.getState();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     *   <li>{@link LoggingSelectorsTop}</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types or has property with incompatible value
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof LoggingSelectorsTop castArg) {
            this._selectors = castArg.getSelectors();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[LoggingSelectorsTop]");
    }


    /**
     * Return current value associated with the property corresponding to {@link RemoteServer#key()}.
     *
     * @return current value
     */
    public RemoteServerKey key() {
        return key;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link RemoteServer#getConfig()}.
     *
     * @return current value
     */
    public Config getConfig() {
        return _config;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link RemoteServer#getHost()}.
     *
     * @return current value
     */
    public Host getHost() {
        return _host;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link RemoteServer#getSelectors()}.
     *
     * @return current value
     */
    public Selectors getSelectors() {
        return _selectors;
    }
    
    /**
     * Return current value associated with the property corresponding to {@link RemoteServer#getState()}.
     *
     * @return current value
     */
    public State getState() {
        return _state;
    }

    /**
     * Return the specified augmentation, if it is present in this builder.
     *
     * @param <E$$> augmentation type
     * @param augmentationType augmentation type class
     * @return Augmentation object from this builder, or {@code null} if not present
     * @throws NullPointerException if {@code augmentType} is {@code null}
     */
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<RemoteServer>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    /**
     * Set the key value corresponding to {@link RemoteServer#key()} to the specified
     * value.
     *
     * @param key desired value
     * @return this builder
     */
    public RemoteServerBuilder withKey(final RemoteServerKey key) {
        this.key = key;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link RemoteServer#getConfig()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public RemoteServerBuilder setConfig(final Config value) {
        this._config = value;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link RemoteServer#getHost()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public RemoteServerBuilder setHost(final Host value) {
        this._host = value;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link RemoteServer#getSelectors()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public RemoteServerBuilder setSelectors(final Selectors value) {
        this._selectors = value;
        return this;
    }
    
    /**
     * Set the property corresponding to {@link RemoteServer#getState()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public RemoteServerBuilder setState(final State value) {
        this._state = value;
        return this;
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public RemoteServerBuilder addAugmentation(Augmentation<RemoteServer> augmentation) {
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentation.implementedInterface(), augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public RemoteServerBuilder removeAugmentation(Class<? extends Augmentation<RemoteServer>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    /**
     * A new {@link RemoteServer} instance.
     *
     * @return A new {@link RemoteServer} instance.
     */
    public @NonNull RemoteServer build() {
        return new RemoteServerImpl(this);
    }

    private static final class RemoteServerImpl
        extends AbstractAugmentable<RemoteServer>
        implements RemoteServer {
    
        private final Config _config;
        private final Host _host;
        private final Selectors _selectors;
        private final State _state;
        private final RemoteServerKey key;
    
        RemoteServerImpl(RemoteServerBuilder base) {
            super(base.augmentation);
            if (base.key() != null) {
                this.key = base.key();
            } else {
                this.key = new RemoteServerKey(base.getHost());
            }
            this._host = key.getHost();
            this._config = base.getConfig();
            this._selectors = base.getSelectors();
            this._state = base.getState();
        }
    
        @Override
        public RemoteServerKey key() {
            return key;
        }
        
        @Override
        public Config getConfig() {
            return _config;
        }
        
        @Override
        public Host getHost() {
            return _host;
        }
        
        @Override
        public Selectors getSelectors() {
            return _selectors;
        }
        
        @Override
        public State getState() {
            return _state;
        }
    
        @Override
        public Config nonnullConfig() {
            return Objects.requireNonNullElse(getConfig(), org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.remote.top.remote.servers.remote.server.ConfigBuilder.empty());
        }
        
        
        @Override
        public Selectors nonnullSelectors() {
            return Objects.requireNonNullElse(getSelectors(), org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.selectors.top.SelectorsBuilder.empty());
        }
        
        @Override
        public State nonnullState() {
            return Objects.requireNonNullElse(getState(), org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.remote.top.remote.servers.remote.server.StateBuilder.empty());
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = RemoteServer.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return RemoteServer.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return RemoteServer.bindingToString(this);
        }
    }
}
